<?php


function penci_amp_get_permalink( $post_id ) {
	$pre_url = apply_filters( 'penci_amp_pre_get_permalink', false, $post_id );

	if ( false !== $pre_url ) {
		return $pre_url;
	}

	$structure = get_option( 'permalink_structure' );
	if ( empty( $structure ) ) {
		$penci_amp_url = add_query_arg( PENCI_AMP_QUERY_VAR, 1, get_permalink( $post_id ) );
	} else {
		$penci_amp_url = trailingslashit( get_permalink( $post_id ) ) . user_trailingslashit( PENCI_AMP_QUERY_VAR, 'single_amp' );
	}

	return apply_filters( 'penci_amp_get_permalink', $penci_amp_url, $post_id );
}

function penci_post_supports_amp( $post ) {
	// Because `add_rewrite_endpoint` doesn't let us target specific post_types :(
	if ( ! post_type_supports( $post->post_type, PENCI_AMP_QUERY_VAR ) ) {
		return false;
	}

	if ( post_password_required( $post ) ) {
		return false;
	}

	if ( true === apply_filters( 'penci_amp_skip_post', false, $post->ID, $post ) ) {
		return false;
	}

	return true;
}

/**
 * Are we currently on an AMP URL?
 *
 * Note: will always return `false` if called before the `parse_query` hook.
 */
function is_penci_amp_endpoint() {
	if ( 0 === did_action( 'parse_query' ) ) {
		_doing_it_wrong( __FUNCTION__, sprintf( esc_html__( "is_penci_amp_endpoint() was called before the 'parse_query' hook was called. This function will always return 'false' before the 'parse_query' hook is called.", 'penci-amp' ) ), '0.4.2' );
	}

	return false !== get_query_var( PENCI_AMP_QUERY_VAR, false );
}

function penci_amp_get_asset_url( $file ) {
	return plugins_url( sprintf( 'assets/%s', $file ), PENCI_AMP_FILE );
}


function penci_amp_get_branding_info( $pos = 'header' ) {

	$info = array(
		'logo'        => '',
		'logo-tag'    => '',
		'name'        => get_bloginfo( 'name', 'display' ),
		'description' => get_bloginfo( 'description', 'display' ),
		'class_img'   => ''
	);

	;

	$id_text_logo = 'penci_amp_header_text_logo';
	$id_img_logo  = 'penci_amp_img_logo';

	if ( 'sidebar' == $pos ) {
		$id_img_logo = 'penci_amp_img_logo_sidebar';
	}

	$name            = penci_amp_get_setting( $id_text_logo );
	$logo            = penci_amp_get_setting( $id_img_logo );
	$mobile_nav_logo = get_theme_mod( 'penci_mobile_nav_logo' );

	// Text logo
	if ( $name ) {
		$info['name'] = $name;
	}

	if ( $logo ) {

		$logo = wp_get_attachment_image_src( $logo, 'full' );

		if ( $logo ) {
			$logo = array(
				'src'    => isset( $logo[0] ) ? $logo[0] : '',
				'width'  => isset( $logo[1] ) ? $logo[1] : '',
				'height' => isset( $logo[2] ) ? $logo[2] : '',
			);
		}

		if ( ! empty( $logo['src'] ) ) {
			$info['logo']        = $logo;
			$info['logo']['alt'] = $info['name'] . ' - ' . $info['description'];

			$info['logo-tag'] = '<amp-img src="' . $logo['src'] . '" alt="' . $info['name'] . ' - ' . $info['description'] . '" height="' . $logo['height'] . '" width="' . $logo['width'] . '"></amp-img>';
		}
	}elseif( $mobile_nav_logo && ! $name ){
		$info['logo-tag'] = '<amp-img src="' . $mobile_nav_logo . '" alt="' . get_bloginfo( 'name', 'display' ) . '" height="50" width="230"></amp-img>';
	}

	return $info;
}


if ( ! function_exists( 'penci_amp_customizer_hidden_attr' ) ) {
	function penci_amp_customizer_hidden_attr( $option_id, $echo = true ) {
		$style = '';

		if ( ! penci_amp_get_setting( $option_id ) ) {
			$style = ' style="display:none !important;"';
		}

		if ( ! $echo ) {
			return $style;
		}

		echo $style;
	}
}

if ( ! function_exists( 'penci_amp_get_search_page_url' ) ) {
	/**
	 * Get search page url
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	function penci_amp_get_search_page_url() {

		return esc_url( add_query_arg( 's', '', site_url( '/amp/' ) ) );
	}
}

/**
 * Detects Non-AMP URL of current page
 *
 *
 * @return string|void
 */
function penci_amp_guess_none_amp_url() {

	static $none_penci_amp_url;

	if ( $none_penci_amp_url ) {
		return $none_penci_amp_url;
	}

	$abspath_fix         = str_replace( '\\', '/', ABSPATH );
	$script_filename_dir = dirname( $_SERVER['SCRIPT_FILENAME'] );

	if ( $script_filename_dir . '/' == $abspath_fix ) {
		// Strip off any file/query params in the path
		$path = preg_replace( '#/[^/]*$#i', '', $_SERVER['PHP_SELF'] );

	} else {
		if ( false !== strpos( $_SERVER['SCRIPT_FILENAME'], $abspath_fix ) ) {
			// Request is hitting a file inside ABSPATH
			$directory = str_replace( ABSPATH, '', $script_filename_dir );
			// Strip off the sub directory, and any file/query params
			$path = preg_replace( '#/' . preg_quote( $directory, '#' ) . '/[^/]*$#i', '', $_SERVER['REQUEST_URI'] );
		} elseif ( false !== strpos( $abspath_fix, $script_filename_dir ) ) {
			// Request is hitting a file above ABSPATH
			$subdirectory = substr( $abspath_fix, strpos( $abspath_fix, $script_filename_dir ) + strlen( $script_filename_dir ) );
			// Strip off any file/query params from the path, appending the sub directory to the install
			$path = preg_replace( '#/[^/]*$#i', '', $_SERVER['REQUEST_URI'] ) . $subdirectory;
		} else {
			$path = $_SERVER['REQUEST_URI'];
		}
	}

	$penci_amp_qv = PENCI_STARTPOINT;

	/**
	 * Fix For Multisite Installation
	 */
	if ( is_multisite() && ! is_main_site() ) {
		$current_site_url = get_site_url();
		$append_path      = str_replace( get_site_url( get_current_site()->blog_id ), '', $current_site_url );

		if ( $append_path !== $current_site_url ) {
			$path .= $append_path;
		}
	}

	if ( preg_match( "#^$path/*$penci_amp_qv/+(.*?)$#", $_SERVER['REQUEST_URI'], $matched ) ) {

		$none_penci_amp_url = site_url( $matched[1] );
	} else {
		$none_penci_amp_url = site_url();
	}

	return $none_penci_amp_url;
}

if ( ! function_exists( 'is_penci_amp' ) ) {
	/**
	 * Detect is the query for an AMP page?
	 *
	 * @since 1.0.0
	 *
	 * @param null $wp_query
	 * @param bool $default
	 *
	 * @return bool true when amp page requested
	 */
	function is_penci_amp( $wp_query = null, $default = false ) {

		if ( $wp_query instanceof WP_Query ) {
			return $wp_query->get( PENCI_STARTPOINT, $default );
		}

		if ( did_action( 'template_redirect' ) ) {

			global $wp_query;

			// check the $wp_query
			if ( is_null( $wp_query ) ) {
				return false;
			} else {
				return $wp_query->get( PENCI_STARTPOINT, $default );
			}

		} else {
			$path   = penci_amp_get_wp_installation_slug();
			$amp_qv = defined( 'PENCI_AMP_QUERY_VAR' ) ? PENCI_AMP_QUERY_VAR : 'amp';

			return preg_match( "#^$path/*(.*?)/$amp_qv/+#", $_SERVER['REQUEST_URI'] );
		}
	}

}

if ( ! function_exists( 'penci_amp_get_wp_installation_slug' ) ) {
	function penci_amp_get_wp_installation_slug() {

		static $path;

		if ( $path ) {
			return $path;
		}

		$abspath_fix         = str_replace( '\\', '/', ABSPATH );
		$script_filename_dir = dirname( $_SERVER['SCRIPT_FILENAME'] );

		if ( $script_filename_dir . '/' == $abspath_fix ) {
			// Strip off any file/query params in the path
			$path = preg_replace( '#/[^/]*$#i', '', $_SERVER['PHP_SELF'] );

		} else if ( FALSE !== strpos( $_SERVER['SCRIPT_FILENAME'], $abspath_fix ) ) {
			// Request is hitting a file inside ABSPATH
			$directory = str_replace( ABSPATH, '', $script_filename_dir );
			// Strip off the sub directory, and any file/query params
			$path = preg_replace( '#/' . preg_quote( $directory, '#' ) . '/[^/]*$#i', '', $_SERVER['REQUEST_URI'] );
		} elseif ( FALSE !== strpos( $abspath_fix, $script_filename_dir ) ) {
			// Request is hitting a file above ABSPATH
			$subdirectory = substr( $abspath_fix, strpos( $abspath_fix, $script_filename_dir ) + strlen( $script_filename_dir ) );
			// Strip off any file/query params from the path, appending the sub directory to the install
			$path = preg_replace( '#/[^/]*$#i', '', $_SERVER['REQUEST_URI'] ) . $subdirectory;
		} else {
			$path = $_SERVER['REQUEST_URI'];
		}


		if ( is_multisite() && ! is_main_site() ) {
			$current_site_url = get_site_url();
			$append_path      = str_replace( get_site_url( get_current_site()->blog_id ), '', $current_site_url );

			if ( $append_path !== $current_site_url ) {
				$path .= $append_path;
			}
		}

		return $path;
	}
}


function penci_amp_get_post_meta( $style = '' ) {

	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date( 'M j, Y' ) ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	echo '<span class="entry-meta-item penci-posted-on" ' . $style . '><i class="fa fa-clock-o"></i>' . $time_string . '</span>'; // WPCS: XSS OK.
}

/**
 * Fallback when menu location is not checked
 * Callback function in wp_nav_menu() on header.php
 *
 * @since 1.0
 */
function penci_amp_menu_fallback() {
	if ( ! current_user_can( 'manage_options' ) ) {
		wp_page_menu();
	} else {
		echo '<ul class="menu"><li class="menu-item-first"><a href="' . esc_url( home_url( '/' ) ) . 'wp-admin/nav-menus.php?action=locations">' . penci_amp_get_setting( 'penci_amp_text_select_menu' ) . '</a></li></ul>';
	}
}

if ( ! function_exists( 'penci_amp_get_site_url' ) ) {
	/**
	 * Get AMP index page url
	 *
	 * @param string $path Optional. Path relative to the site URL. Default empty.
	 *
	 * @since 1.0.0
	 *
	 * @return string
	 */
	function penci_amp_get_site_url( $path = '' ) {

		$url = site_url( '/' . PENCI_STARTPOINT );

		if ( $path ) {
			$url .= $path;
		}

		return $url;
	}
}


if ( ! function_exists( 'penci_amp_post_thumbnail' ) ) {
	/**
	 * Display post thumbnail. Use featured image first and fallback to first image in the post content
	 *
	 * @param array $args
	 *
	 * @return bool
	 */
	function penci_amp_post_thumbnail( $args = array() ) {
		$args = wp_parse_args( $args, array(
			'post'       => null,
			'class'      => 'penci-post-thumb',
			'size'       => 'thumbnail',
			'return_url' => false,
			'before'     => '',
			'after'      => '',
			'echo'       => true,
		) );

		$url       = '';
		$image_alt = esc_html__( 'Default image', 'penci-amp' );

		$image_size_info = penci_amp_get_image_sizes( $args['size'] );

		// Get post thumbnail
		if ( has_post_thumbnail( $args['post'] ) ) {
			$post_thumbnail_id = get_post_thumbnail_id( $args['post'] );
			$image_alt         = get_post_meta( $post_thumbnail_id, '_wp_attachment_image_alt', true );
			$url               = wp_get_attachment_image_url( $post_thumbnail_id, $args['size'] );
		}

		if ( empty( $url ) ) {

			$link_url = 'images/no-thumb.jpg';

			if( false !== strpos( $args['size'], 'shop' ) ) {
				$link_url = 'images/no-image-product.jpg';
			}

			$url = penci_amp_get_asset_url( $link_url );
		}

		if ( $args['return_url'] ) {
			return $url;
		}

		$image = '<amp-img class="' . $args['class'] . '" src="' . $url . '" alt="' . $image_alt . '" width="' . $image_size_info['width'] . '" height="' . $image_size_info['height'] . '" layout="responsive"></amp-img>';

		$image = $args['before'] . $image . $args['after'];

		if ( ! $args['echo'] ) {
			return $image;
		}

		echo $image;
	}
}

if ( ! function_exists( 'penci_amp_get_image_sizes' ) ) {
	/**
	 * Get size information for all currently-registered image sizes.
	 *
	 * @param $_size
	 *
	 * @return array
	 */
	function penci_amp_get_image_sizes( $_size ) {
		global $_wp_additional_image_sizes;

		$info = array(
			'width'  => '480',
			'height' => '320',
		);
		if ( in_array( $_size, array( 'thumbnail', 'medium', 'medium_large', 'large' ) ) ) {
			$info['width']  = get_option( "{$_size}_size_w" );
			$info['height'] = get_option( "{$_size}_size_h" );
		} elseif ( isset( $_wp_additional_image_sizes[ $_size ] ) ) {
			$info = array(
				'width'  => $_wp_additional_image_sizes[ $_size ]['width'],
				'height' => $_wp_additional_image_sizes[ $_size ]['height'],
			);
		}

		return $info;
	}
}

function penci_amp_default_theme_logo() {

	ob_start();
	$site_branding = penci_amp_get_branding_info(  );

	$class_img = $site_branding['class_img'];
	$class_img .= ! empty( $site_branding['logo-tag'] ) ? ' penci-amp-site-icon image-logo' : ' text-logo';

	?>
	<a href="<?php echo esc_url( penci_amp_get_site_url() ); ?>"
	   class="branding <?php echo $class_img; ?> ">
		<?php

		if ( ! empty( $site_branding['logo-tag'] ) ) {
			echo $site_branding['logo-tag']; // escaped before
		} else {
			echo $site_branding['name']; // escaped before
		}

		?>
	</a>
	<?php

	return ob_get_clean();
}

if ( ! function_exists( 'penci_amp_get_archive_title' ) ) {
	/**
	 * Handy function used to get archive pages title fields
	 *
	 * @return array
	 */
	function penci_amp_get_archive_title() {

		$icon      = '';
		$sub_title = '';
		$title     = '';

		if ( function_exists( 'is_woocommerce' ) && is_woocommerce() ) {
			
			if ( is_product_category() ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_product_category' );
				$title     = single_term_title( '', false );
			} elseif ( is_product_tag() ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_product_tag' );
				$title     = single_term_title( '', false );
			} else {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing' );
				$title     = penci_amp_get_setting( 'penci_amp_product-shop' );
			}

		} elseif ( is_category() ) {
			$sub_title = penci_amp_get_setting( 'penci_amp_browsing_category' );
			$title     = single_cat_title( '', false );
		} elseif ( is_tag() ) {
			$sub_title = penci_amp_get_setting( 'penci_amp_browsing_tag' );
			$title     = single_tag_title( '', false );
		} elseif ( is_author() ) {
			$sub_title = penci_amp_get_setting( 'penci_amp_browsing_author' );
			$title     = '<span class="vcard">' . get_the_author() . '</span>';
		} elseif ( is_year() ) {
			$sub_title = penci_amp_get_setting( 'penci_amp_browsing_yearly' );
			$title     = get_the_date( _x( 'Y', 'yearly archives date format', 'penci-amp' ) );
		} elseif ( is_month() ) {
			$sub_title = penci_amp_get_setting( 'penci_amp_browsing_monthly' );
			$title     = get_the_date( _x( 'F Y', 'monthly archives date format', 'penci-amp' ) );
		} elseif ( is_day() ) {
			$sub_title = penci_amp_get_setting( 'penci_amp_browsing_daily' );
			$title     = get_the_date( _x( 'F j, Y', 'daily archives date format', 'penci-amp' ) );
		} elseif ( is_tax( 'post_format' ) ) {
			if ( is_tax( 'post_format', 'post-format-aside' ) ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
				$title     = penci_amp_get_setting( 'penci_amp_asides' );
			} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
				$title     = penci_amp_get_setting( 'penci_amp_galleries' );
			} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
				$title     = penci_amp_get_setting( 'penci_amp_images' );
			} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
				$title     = penci_amp_get_setting( 'penci_amp_videos' );
			}  elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
				$title     = penci_amp_get_setting( 'penci_amp_links' );
			} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
				$title     = penci_amp_get_setting( 'penci_amp_statuses' );
			} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
				$title     = penci_amp_get_setting( 'penci_amp_audio' );
			} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
				$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
				$title     = penci_amp_get_setting( 'penci_amp_chats' );
			}
		} elseif ( is_post_type_archive() ) {
			$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
			$title     = post_type_archive_title( '', false );
		} elseif ( is_tax() ) {

			$tax = get_taxonomy( get_queried_object()->taxonomy );

			$sub_title = penci_amp_get_setting( 'penci_amp_browsing_archive' );
			$title     = sprintf( __( '%1$s: %2$s', 'beetter-amp' ), $tax->labels->singular_name, single_term_title( '', false ) );
		} else {
			$sub_title = penci_amp_get_setting( 'penci_amp_browsing' );
			$title     = penci_amp_get_setting( 'penci_amp_archive' );
		}

		return compact( 'icon', 'sub_title', 'title' );
	}
}


function penci_amp_customize_typo_body() {
	$font_family = penci_amp_get_setting( 'penci_amp_font_for_body' );
	$font_weight = penci_amp_get_setting( 'penci_amp_font_weight_body' );
	$font_size   = penci_amp_get_setting( 'penci_amp_font_for_size_body' );

	$css = '';
	if ( $font_family ) {
		$css .= sprintf( 'font-family: %s;', penci_amp_google_fonts_parse_attributes( $font_family ) );
	}

	if ( $font_weight ) {
		$css .= sprintf( 'font-weight: %s;', $font_weight );
	}

	if ( $font_size ) {
		$css .= sprintf( 'font-size: %spx;', $font_size );
	}

	return $css;
}

function penci_amp_customize_typo_title() {
	$font_family = penci_amp_get_setting( 'penci_amp_font_for_title' );
	$font_weight = penci_amp_get_setting( 'penci_amp_font_weight_title' );
	$css = '';
	if ( $font_family ) {
		$css .= sprintf( 'font-family: %s;', penci_amp_google_fonts_parse_attributes( $font_family ) );
	}

	if ( $font_weight ) {
		$css .= sprintf( 'font-weight: %s;', $font_weight );
	}

	return $css;
}

function penci_amp_google_fonts_parse_attributes( $font_family ) {
	$penci_font_browser = function_exists( 'penci_font_browser' ) ? penci_font_browser() : array();
	if ( in_array( $font_family, $penci_font_browser ) ) {
		return $font_family;
	}

	$font_family     = str_replace( '"', '', $font_family );
	$font_explo      = explode( ", ", $font_family );
	$font            = isset( $font_explo[0] ) ? $font_explo[0] : '';
	$font_serif      = isset( $font_explo[2] ) ? $font_explo[2] : '';
	$font_type       = isset( $font_explo[1] ) ? str_replace( ':', ',', $font_explo[1] ) : '';
	$font_replace    = str_replace( ' ', '+', $font );
	$font_family_end = "'" . $font . "', " . $font_serif;

	wp_enqueue_style( penci_amp_build_safe_css_class( urlencode( $font ) ), '//fonts.googleapis.com/css?family=' . esc_attr( $font_replace ) . ':' . esc_attr( $font_type ) );

	return $font_family_end;
}

function penci_amp_build_safe_css_class( $class ) {
	return preg_replace( '/\W+/', '', strtolower( str_replace( ' ', '_', strip_tags( $class ) ) ) );
}