<?php
// Callbacks for adding content to an AMP template

function penci_amp_post_template_init_hooks() {
	add_action( 'penci_amp_post_template_head', 'penci_amp_post_template_add_title' );
	add_action( 'penci_amp_post_template_head', 'penci_amp_post_template_add_enqueue_static' );
	add_action( 'penci_amp_post_template_head', 'penci_amp_post_template_add_canonical' );
	add_action( 'penci_amp_post_template_head', 'penci_amp_post_template_add_scripts' );
	add_action( 'penci_amp_post_template_head', 'penci_amp_post_template_add_fonts' );
	add_action( 'penci_amp_post_template_head', 'penci_amp_post_template_add_boilerplate_css' );
	add_action( 'penci_amp_post_template_head', 'penci_amp_post_template_add_schemaorg_metadata' );
	add_action( 'penci_amp_post_template_css', 'penci_amp_post_template_add_styles', 99 );
	add_action( 'penci_amp_post_template_data', 'penci_amp_post_template_add_analytics_script' );
	add_action( 'penci_amp_post_template_footer', 'penci_amp_post_template_add_analytics_data' );
}

function penci_amp_post_template_add_enqueue_static( $penci_amp_template ){
	wp_enqueue_style( 'teko', 'https://fonts.googleapis.com/css?family=Teko:300,400,500,600,700' );
	wp_enqueue_style( 'opensans', 'https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,600i,700,700i,800,800i' );
	wp_enqueue_style( 'roboto', 'https://fonts.googleapis.com/css?family=Roboto:100,100i,300,300i,400,400i,500,500i,700,700i' )

	?>
	<link rel="stylesheet" id="font-awesome-css" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css" type="text/css" media="all">
	<script async custom-element="amp-sidebar" src="https://cdn.ampproject.org/v0/amp-sidebar-0.1.js"></script>
	<script async custom-element="amp-accordion" src="https://cdn.ampproject.org/v0/amp-accordion-0.1.js"></script>
	<script async custom-element="amp-carousel" src="https://cdn.ampproject.org/v0/amp-carousel-0.1.js"></script>
	<?php
}

function penci_amp_post_template_add_title( $penci_amp_template ) {
	?>
	<title><?php echo esc_html( $penci_amp_template->get( 'document_title' ) ); ?></title>
	<?php
}

function penci_amp_post_template_add_canonical( $penci_amp_template ) {
	?>
	<link rel="canonical" href="<?php echo esc_url( $penci_amp_template->get( 'canonical_url' ) ); ?>" />
	<?php
}

function penci_amp_post_template_add_scripts( $penci_amp_template ) {
	$scripts = $penci_amp_template->get( 'penci_amp_component_scripts', array() );
	foreach ( $scripts as $element => $script ) :
		$custom_type = ($element == 'amp-mustache') ? 'template' : 'element'; ?>
		<script custom-<?php echo esc_attr( $custom_type ); ?>="<?php echo esc_attr( $element ); ?>" src="<?php echo esc_url( $script ); ?>" async></script>
	<?php endforeach; ?>
	<script src="<?php echo esc_url( $penci_amp_template->get( 'penci_amp_runtime_script' ) ); ?>" async></script>
	<?php
}

function penci_amp_post_template_add_fonts( $penci_amp_template ) {
	$font_urls = $penci_amp_template->get( 'font_urls', array() );
	foreach ( $font_urls as $slug => $url ) : ?>
		<link rel="stylesheet" href="<?php echo esc_url( $url ); ?>">
	<?php endforeach;
}

function penci_amp_post_template_add_boilerplate_css( $penci_amp_template ) {
	?>
	<style amp-boilerplate>body{-webkit-animation:-amp-start 8s steps(1,end) 0s 1 normal both;-moz-animation:-amp-start 8s steps(1,end) 0s 1 normal both;-ms-animation:-amp-start 8s steps(1,end) 0s 1 normal both;animation:-amp-start 8s steps(1,end) 0s 1 normal both}@-webkit-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@-moz-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@-ms-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@-o-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}</style><noscript><style amp-boilerplate>body{-webkit-animation:none;-moz-animation:none;-ms-animation:none;animation:none}</style></noscript>
	<?php
}

function penci_amp_post_template_add_schemaorg_metadata( $penci_amp_template ) {
	$metadata = $penci_amp_template->get( 'metadata' );
	if ( empty( $metadata ) ) {
		return;
	}
	?>
	<script type="application/ld+json"><?php echo wp_json_encode( $metadata ); ?></script>
	<?php
}

function penci_amp_post_template_add_styles( $penci_amp_template ) {
	$styles = $penci_amp_template->get( 'post_penci_amp_styles' );
	if ( ! empty( $styles ) ) {
		echo '/* Inline styles */' . PHP_EOL;
		foreach ( $styles as $selector => $declarations ) {
			$declarations = implode( ';', $declarations ) . ';';
			printf( '%1$s{%2$s}', $selector, $declarations );
		}
	}
}

function penci_amp_post_template_add_analytics_script( $data ) {
	if ( ! empty( $data['penci_amp_analytics'] ) ) {
		$data['penci_amp_component_scripts']['amp-analytics'] = 'https://cdn.ampproject.org/v0/amp-analytics-0.1.js';
	}
	return $data;
}

function penci_amp_post_template_add_analytics_data( $penci_amp_template ) {
	$analytics_entries = $penci_amp_template->get( 'penci_amp_analytics' );
	if ( empty( $analytics_entries ) ) {
		return;
	}

	foreach ( $analytics_entries as $id => $analytics_entry ) {
		if ( ! isset( $analytics_entry['type'], $analytics_entry['attributes'], $analytics_entry['config_data'] ) ) {
			_doing_it_wrong( __FUNCTION__, sprintf( esc_html__( 'Analytics entry for %s is missing one of the following keys: `type`, `attributes`, or `config_data` (array keys: %s)', 'penci-amp' ), esc_html( $id ), esc_html( implode( ', ', array_keys( $analytics_entry ) ) ) ), '0.3.2' );
			continue;
		}
		$script_element = Penci_AMP_HTML_Utils::build_tag( 'script', array(
			'type' => 'application/json',
		), wp_json_encode( $analytics_entry['config_data'] ) );

		$penci_amp_analytics_attr = array_merge( array(
			'id' => $id,
			'type' => $analytics_entry['type'],
		), $analytics_entry['attributes'] );

		echo Penci_AMP_HTML_Utils::build_tag( 'amp-analytics', $penci_amp_analytics_attr, $script_element );
	}
}
