<?php

class Penci_AMP_Href_Sanitizer {

	/**
	 * Store array of posts id to exlucde transform permalinks to amp
	 * @var array
	 */
	public $excluded_posts_id = array();

	public function __construct() {

		$is_penci_amp = is_penci_amp();
		
		if ( empty( $is_penci_amp ) ) {
			return;
		}
		add_action( 'penci_amp_init', array( $this, 'replace_internal_links' ) );
	}

	public function replace_internal_links() {
		add_filter( 'nav_menu_link_attributes', array( $this, 'replace_href_with_amp' ) );
		add_filter( 'the_content', array( $this, 'transform_all_links_to_amp' ) );
		add_filter( 'author_link', array( $this, 'transform_to_amp_url' ) );
		add_filter( 'term_link', array( $this, 'transform_to_amp_url' ) );

		add_filter( 'post_link', array( $this, 'transform_post_link_to_amp' ), 20, 2 );
		add_filter( 'page_link', array( $this, 'transform_post_link_to_amp' ), 20, 2 );
		add_filter( 'attachment_link', array( $this, 'transform_to_amp_url' ) );
		add_filter( 'post_type_link', array( $this, 'transform_to_amp_url' ) );
	}

	/**
	 * Replace internal links with amp version just in href attribute
	 *
	 * @param array $attr list of attributes
	 *
	 * @return array
	 */
	public function replace_href_with_amp( $attr ) {

		if ( isset( $attr['href'] ) ) {
			$attr['href'] = $this->transform_to_amp_url( $attr['href'] );
		}

		return $attr;
	}

	/**
	 * Convert all links in html content to amp link
	 * Except links which is started with wp-content
	 *
	 * @return string
	 */
	public function transform_all_links_to_amp( $content ) {

		$pattern = "'<\s*a\s(.*?)href\s*=\s*	    # find <a href=
						([\"\'])?					# find single or double quote
						(?(2) (.*?)\\2 | ([^\s\>]+))		# if quote found, match up to next matching
													# quote, otherwise match up to next space
						'isx";

		return preg_replace_callback( $pattern, array( $this, '_preg_replace_link_callback' ), $content );
	}

	/**
	 * Callback function for preg_replace_callback
	 * to replace html href="" links to amp version
	 *
	 * @param  array $match pattern matches
	 *
	 * @access private
	 *
	 * @since  1.0.0
	 *
	 * @return string
	 */
	private function _preg_replace_link_callback( $match ) {

		$url  = empty( $match[4] ) ? $match[3] : $match[4];
		$url  = $this->transform_to_amp_url( $url );
		$atts = &$match[1];
		$q    = &$match[2];

		return sprintf( '<a %1$shref=%2$s%3$s%2$s', $atts, $q, esc_attr( $url ) );
	}

	/**
	 * Convert $url to amp version if:
	 * 1) $url was internal
	 * 2) disable flag is not true  {@see turn_url_transform_off_on}
	 *
	 * @param string $url
	 *
	 * @since 1.0.0
	 *
	 * @return string transformed amp url on success or passed $url otherwise.
	 */
	public static function transform_to_amp_url( $url ) {

		// todo support parked domains
		$sitedomain = str_replace(
			array(
				'http://www.',
				'https://www.',
				'http://',
				'https://',
			),
			'',
			site_url()
		);

		$sitedomain = rtrim( $sitedomain, '/' );

		if ( preg_match( '#^https?://w*\.?' . preg_quote( $sitedomain, '#' ) . '/?([^/]*)/?(.*?)$#', $url, $matched ) ) {

			// if url was not amp
			if ( $matched[1] !== PENCI_STARTPOINT ) {

				if ( $matched[1] !== 'wp-content' ) { // do not convert link which is started with wp-content
					if ( $matched[1] ) {
						$matched[0] = '';
						$path       = implode( '/', $matched );
					} else {
						$path = '/';
					}

					return penci_amp_get_site_url( $path );
				}
			}
		}

		return $url;
	}

	/**
	 * Transform allowed posts url to amp
	 *
	 * @param string $url The post's permalink.
	 * @param WP_Post|int $post The post object/id  of the post.
	 *
	 * @since 1.1
	 * @return string
	 */
	public function transform_post_link_to_amp( $url, $post ) {

		$post_id = isset( $post->ID ) ? $post->ID : $post;

		if ( isset( $this->excluded_posts_id[ $post_id ] ) ) {
			return $url;
		}

		return self::transform_to_amp_url( $url );
	}
}

new Penci_AMP_Href_Sanitizer;