<?php
/**
 * Plugin Name: PenCi Soledad AMP -  WordPress Complete AMP
 * Description: Add AMP support to your WordPress site.
 * Plugin URI: http://pencidesign.com/
 * Author: PenciDesign
 * Author URI: http://themeforest.net/user/pencidesign?ref=pencidesign
 * Version: 1.0
 * Text Domain: penci-amp
 * Domain Path: /languages/
 */

define( 'PENCI_AMP_FILE', __FILE__ );
define( 'PENCI_AMP_DIR', dirname( __FILE__ ) );
define( 'PENCI_AMP_VERSION', '1.0.0' );
define( 'PENCI_STARTPOINT', 'amp' );

require_once( PENCI_AMP_DIR . '/back-compat/back-compat.php' );
require_once( PENCI_AMP_DIR . '/includes/amp-helper-functions.php' );
require_once( PENCI_AMP_DIR . '/includes/admin/functions.php' );
require_once( PENCI_AMP_DIR . '/includes/class-amp-menu-walker.php' );
require_once( PENCI_AMP_DIR . '/includes/class-amp-rewrite-rules.php' );
require_once( PENCI_AMP_DIR . '/includes/class-amp-woocommerce.php' );

require_once( PENCI_AMP_DIR . '/includes/sanitizers/class-amp-href-sanitizer.php' );
require_once( PENCI_AMP_DIR . '/includes/settings/default-setting.php' );
require_once( PENCI_AMP_DIR . '/includes/settings/class-amp-customizer-settings.php' );
require_once( PENCI_AMP_DIR . '/includes/settings/class-amp-customizer-design-settings.php' );

register_activation_hook( __FILE__, 'penci_amp_activate' );
function penci_amp_activate() {
	if ( ! did_action( 'penci_amp_init' ) ) {
		penci_amp_init();
	}
	flush_rewrite_rules();
}

register_deactivation_hook( __FILE__, 'penci_amp_deactivate' );
function penci_amp_deactivate() {
	// We need to manually remove the amp endpoint
	global $wp_rewrite;
	foreach ( $wp_rewrite->endpoints as $index => $endpoint ) {
		if ( PENCI_AMP_QUERY_VAR === $endpoint[1] ) {
			unset( $wp_rewrite->endpoints[ $index ] );
			break;
		}
	}

	flush_rewrite_rules();
}

add_action( 'init', 'penci_amp_init' );
function penci_amp_init() {
	if ( false === apply_filters( 'penci_amp_is_enabled', true ) ) {
		return;
	}


	define( 'PENCI_AMP_QUERY_VAR', apply_filters( 'penci_amp_query_var', PENCI_STARTPOINT ) );

	do_action( 'penci_amp_init' );


	load_plugin_textdomain( 'penci-amp', false, plugin_basename( PENCI_AMP_DIR ) . '/languages' );
	register_nav_menu( 'penci-amp-sidebar-nav', esc_html__( 'AMP Navigation', 'penci-amp' ) );
	register_nav_menu( 'penci-amp-footer', esc_html__( 'AMP Footer Navigation', 'penci-amp' ) );

	penci_amp_add_rewrite_startpoint( PENCI_STARTPOINT, EP_ALL );

	add_rewrite_endpoint( PENCI_AMP_QUERY_VAR, EP_PERMALINK );

	// Add a rewrite rule to detect site.com/penci-amp/ requests
	add_rewrite_rule( PENCI_AMP_QUERY_VAR . '/?$', "index.php?amp=index", 'top' );



	add_filter( 'request', 'penci_amp_force_query_var_value' );
	add_action( 'wp', 'penci_amp_maybe_add_actions' );

	// Redirect the old url of amp page to the updated url.
	add_filter( 'old_slug_redirect_url', 'penci_amp_redirect_old_slug_to_new_url' );

	if ( class_exists( 'Jetpack' ) && ! ( defined( 'IS_WPCOM' ) && IS_WPCOM ) ) {
		require_once( PENCI_AMP_DIR . '/jetpack-helper.php' );
	}
}

add_action( 'pre_get_posts', 'penci_amp_compatible_plugins_themes',0 );

/**
 * Register missed hooks for supported plugins/themes to bypass isolation
 *
 * @see   isolate_pre_get_posts_start
 * @see   isolate_pre_get_posts_end
 *
 * @since 1.1
 */
function penci_amp_compatible_plugins_themes() {

	$is_penci_amp = is_penci_amp();

	if ( ! $is_penci_amp ) {
		return;
	}
	// WooCommerce compatibility
	if ( class_exists( 'WooCommerce' ) ) {

		$callback = array( WooCommerce::instance()->query, 'pre_get_posts' );

		if ( is_callable( $callback ) ) {
			add_action( 'pre_get_posts', $callback, 100 );
		}

		// WooCommerce didn't change main query in "shop" page
		add_action( 'pre_get_posts', 'penci_amp_fix_woocommerce_shop_page_query', 101 );

	}
}

/**
 * Fixes global WP_Query for shop pages in AMP!
 *
 * @param $q
 */
function penci_amp_fix_woocommerce_shop_page_query( $q ) {

	// We only want to affect the main query
	if ( ! $q->is_main_query() ) {
		return;
	}


	if ( isset( $q->queried_object->ID ) && $q->queried_object->ID === wc_get_page_id( 'shop' ) ) {
		$q->set( 'post_type', 'product' );
		$q->set( 'posts_per_page', 8 );
		$q->set( 'pagename', '' );

		// Fix conditional Functions
		$q->is_archive           = true;
		$q->is_post_type_archive = true;
		$q->is_singular          = false;
		$q->is_page              = true;
	}
}


add_action( 'request', 'penci_fix_search_page_queries' );
/**
 * Handy fix for changing search query
 *
 * @param $q
 * @return mixed
 */
function penci_fix_search_page_queries( $q ) {

	if ( ! empty( $q['amp'] ) && ! empty( $q['s'] ) ) {

		$q['post_type'] = array( 'post' );
	}

	return $q;
}


// Make sure the `amp` query var has an explicit value.
// Avoids issues when filtering the deprecated `query_string` hook.
function penci_amp_force_query_var_value( $query_vars ) {
	if ( isset( $query_vars[ PENCI_AMP_QUERY_VAR ] ) && '' === $query_vars[ PENCI_AMP_QUERY_VAR ] ) {
		$query_vars[ PENCI_AMP_QUERY_VAR ] = 1;
	}

	return $query_vars;
}

function penci_amp_maybe_add_actions() {


	$is_penci_amp_endpoint = is_penci_amp_endpoint();

	if ( is_singular() && ! is_feed() ) {
		add_post_type_support( 'post', PENCI_AMP_QUERY_VAR );
		add_post_type_support( 'product', PENCI_AMP_QUERY_VAR );
		add_post_type_support( 'portfolio', PENCI_AMP_QUERY_VAR );
		// Cannot use `get_queried_object` before canonical redirect; see https://core.trac.wordpress.org/ticket/35344
		global $wp_query;
		$post = $wp_query->post;

		$supports = penci_post_supports_amp( $post );

		if ( ! $supports ) {
			if ( $is_penci_amp_endpoint ) {
				wp_safe_redirect( get_permalink( $post->ID ) );
				exit;
			}
			return;
		}
	}

	if ( $is_penci_amp_endpoint ) {
		penci_amp_prepare_render();
	} else {
		penci_amp_add_frontend_actions();
	}
}

function penci_amp_load_classes() {
	require_once( PENCI_AMP_DIR . '/includes/class-amp-post-template.php' ); // this loads everything else
}

function penci_amp_add_frontend_actions() {
	require_once( PENCI_AMP_DIR . '/includes/amp-frontend-actions.php' );
}

function penci_amp_add_post_template_actions() {
	require_once( PENCI_AMP_DIR . '/includes/amp-post-template-actions.php' );
	require_once( PENCI_AMP_DIR . '/includes/amp-post-template-functions.php' );
	penci_amp_post_template_init_hooks();
}

function penci_amp_prepare_render() {
	add_action( 'template_redirect', 'penci_amp_render' );
}

function penci_amp_render() {
	$post_id = get_queried_object_id();

	penci_amp_render_post( $post_id );
	exit;
}

function penci_amp_render_post( $post_id ) {

	$post = get_post( $post_id );
	if ( ! $post && is_singular() ) {
		return;
	}

	penci_amp_load_classes();

	do_action( 'pre_penci_amp_render_post', $post_id );

	penci_amp_add_post_template_actions();
	$template = new Penci_AMP_Post_Template( $post_id );
	$include = penci_amp_template_loader(  );



	$template->load( $include );
}


/**
 * Get AMP template file base on page of WordPress
 *
 * @link         https://developer.wordpress.org/themes/basics/template-hierarchy/
 * @copyright    credit goes to WordPress team @see wp-includes/template-loader.php
 * @access       private
 *
 * @since        1.0.0
 *
 * @return  string
 */
function penci_amp_template_loader() {

	if ( function_exists( 'is_embed' ) && is_embed()  ) :
		$template = 'embed';
	elseif ( function_exists( 'is_woocommerce' ) && is_woocommerce() ) :
		if ( function_exists( 'is_shop' ) && ( is_shop() || is_product_category() || is_product_tag() ) ):
			$template = 'woocommerce';
		elseif ( is_singular( 'product' ) ):
			$template = 'single-product';
		endif;
	elseif ( is_404() ) :
		$template = 'page404';
	elseif ( is_search( ) ) :
		$template = 'search';
	elseif ( is_front_page() || is_home() ) :
		$template = 'index';
	elseif ( is_post_type_archive() ) :
		$template = 'archive';
	elseif ( is_tax() ) :
		$template = 'archive';
	elseif ( is_attachment() ) :
		$template = 'single';
	elseif ( is_single() ) :
		$template = 'single';
	elseif ( is_page() ) :
		$template = 'single';
	elseif ( is_singular() ) :
		$template = 'single';
	elseif ( is_category() ) :
		$template = 'archive';
	elseif ( is_tag() ) :
		$template = 'archive';
	elseif ( is_author() ) :
		$template = 'archive';
	elseif ( is_date() ) :
		$template = 'archive';
	elseif ( is_archive() ) :
		$template = 'archive';
	elseif ( is_paged() ) :
		$template = 'archive';
	else :
		$template = 'index';
	endif;

	return $template;

}

/**
 * Bootstraps the AMP customizer.
 *
 * If the AMP customizer is enabled, initially drop the core widgets and menus panels. If the current
 * preview page isn't flagged as an AMP template, the core panels will be re-added and the AMP panel
 * hidden.
 *
 * @internal This callback must be hooked before priority 10 on 'plugins_loaded' to properly unhook
 *           the core panels.
 *
 * @since 0.4
 */
function _penci_amp_bootstrap_customizer() {
	/**
	 * Filter whether to enable the AMP template customizer functionality.
	 *
	 * @param bool $enable Whether to enable the AMP customizer. Default true.
	 */
	$penci_amp_customizer_enabled = apply_filters( 'penci_amp_customizer_is_enabled', true );

	if ( true === $penci_amp_customizer_enabled ) {
		penci_amp_init_customizer();
	}
}
add_action( 'plugins_loaded', '_penci_amp_bootstrap_customizer', 9 );

/**
 * Redirects the old AMP URL to the new AMP URL.
 * If post slug is updated the amp page with old post slug will be redirected to the updated url.
 *
 * @param  string $link New URL of the post.
 *
 * @return string $link URL to be redirected.
 */
function penci_amp_redirect_old_slug_to_new_url( $link ) {

	if ( is_penci_amp_endpoint() ) {
		$link = trailingslashit( trailingslashit( $link ) . PENCI_AMP_QUERY_VAR );
	}

	return $link;
}
